@@ -55,7 +55,7 @@ public:
     void shortcutChanged() override;
 
 protected:
-    KParts::ReadOnlyPart *createPart() override;
+    KParts::Part *createPart() override;
 
 private:
     void slotNewContact();
